@@ -1,6 +1,6 @@
 import pytest
 
-def _api(access_token='__MASTODON_PY_TEST_ACCESS_TOKEN', version="2.4.3", version_check_mode="created"):
+def _api(access_token='__MASTODON_PY_TEST_ACCESS_TOKEN', version="2.8.0", version_check_mode="created"):
     import mastodon
     return mastodon.Mastodon(
             api_base_url='http://localhost:3000',
@@ -27,19 +27,19 @@ def api2():
 def api_anonymous():
     return _api(access_token=None)
 
-@pytest.fixture()
+@pytest.fixture
 def status(api):
     _status = api.status_post('Toot!')
     yield _status
     api.status_delete(_status['id'])
 
-@pytest.fixture()
+@pytest.fixture
 def status2(api):
     _status = api.status_post('Toot, too!')
     yield _status
     api.status_delete(_status['id'])
 
-@pytest.fixture()
+@pytest.fixture(scope="module")
 def vcr_config():
     return dict(
             match_on = ['method', 'path', 'query', 'body'],
