@@ -164,12 +164,48 @@ def test_account_pinned(status, status2, api):
         api.status_unpin(status['id'])
 
 @pytest.mark.vcr()
-def test_follow_suggestions(api):
-    suggestions = api.suggestions()
+def test_follow_suggestions(api2, status):
+    api2.status_favourite(status)
+    
+    suggestions = api2.suggestions()
     assert(suggestions)
     assert(len(suggestions) > 0)
     
-    api.suggestion_delete(suggestions[0])
-    suggestions2 = api.suggestions()
+    api2.suggestion_delete(suggestions[0])
+    suggestions2 = api2.suggestions()
     assert(len(suggestions2) < len(suggestions))
     
+@pytest.mark.vcr()
+def test_account_pin_unpin(api, api2):
+    user = api2.account_verify_credentials()
+    
+    # Make sure we are in the correct state
+    try:
+        api.account_follow(user)
+    except:
+        pass
+    
+    try:
+        api.account_unpin(user)
+    except:
+        pass
+    
+    relationship = api.account_pin(user)
+    endorsed = api.endorsements()
+        
+    try:
+        assert relationship
+        assert relationship['endorsed']
+        assert user["id"] in map(lambda x: x["id"], endorsed)
+    finally:
+        relationship = api.account_unpin(user)
+        endorsed2 = api.endorsements()
+        api.account_unfollow(user)        
+        assert relationship
+        assert not relationship['endorsed']
+        assert not user["id"] in map(lambda x: x["id"], endorsed2)
+
+@pytest.mark.vcr()
+def test_preferences(api):
+    prefs = api.preferences()
+    assert prefs
