@@ -1,5 +1,7 @@
 import pytest
 from mastodon.Mastodon import MastodonAPIError, MastodonNotFoundError
+import datetime
+import pytz
 
 @pytest.mark.vcr()
 def test_status(status, api):
@@ -48,6 +50,11 @@ def test_status_reblogged_by(status, api):
     reblogs = api.status_reblogged_by(status['id'])
     assert reblogs
 
+@pytest.mark.vcr()
+def test_status_reblog_visibility(status, api):
+    reblog_result = api.status_reblog(status['id'], visibility = 'unlisted')
+    assert reblog_result.visibility == 'unlisted'
+
 @pytest.mark.vcr()
 def test_status_favourited_by(status, api):
     api.status_favourite(status['id'])
@@ -121,3 +128,26 @@ def test_status_pin_unpin(status, api):
 
     status = api.status_unpin(status['id'])
     assert not status['pinned']
+
+@pytest.mark.vcr(match_on=['path'])
+def test_scheduled_status(api):
+    base_time = datetime.datetime(4000, 1, 1, 12, 13, 14, 0, pytz.timezone("Etc/GMT+2"))
+    the_future = base_time + datetime.timedelta(minutes=20)
+    scheduled_toot = api.status_post("please ensure adequate headroom", scheduled_at=the_future)
+    assert scheduled_toot
+
+    the_immediate_future = base_time + datetime.timedelta(minutes=10)
+    scheduled_toot_2 = api.scheduled_status_update(scheduled_toot, the_immediate_future)
+    assert scheduled_toot_2
+    assert scheduled_toot_2.id == scheduled_toot.id
+    assert scheduled_toot_2.scheduled_at < scheduled_toot.scheduled_at
+
+    scheduled_toot_list = api.scheduled_statuses()
+    assert scheduled_toot_2.id in map(lambda x: x.id, scheduled_toot_list)
+
+    scheduled_toot_3 = api.scheduled_status(scheduled_toot.id)
+    assert scheduled_toot_2.id == scheduled_toot_3.id
+
+    api.scheduled_status_delete(scheduled_toot_2)
+    scheduled_toot_list_2 = api.scheduled_statuses()
+    assert not scheduled_toot_2.id in map(lambda x: x.id, scheduled_toot_list_2)
